__name__ = "yamlconf"
__version__ = "0.2.5"
__author__ = "Aaron Halfaker"
__author_email__ = "aaron.halfaker@gmail.com"
__description__ = "Yaml-based configuration file reader."
__license__ = "MIT"
__url__ = "https://github.com/halfak/yamlconf"

all = [__name__, __version__, __author__, __author_email__, __description__,
       __license__, __url__]
